# eric7.Plugins.VcsPlugins.vcsGit.GitSubmodulesListDialog

Module implementing a dialog to list the defined submodules.

### Global Attributes

None

### Classes

GitSubmodulesListDialog | Class implementing a dialog to list the defined submodules.

### Functions

None

## GitSubmodulesListDialog

Class implementing a dialog to list the defined submodules.

### Derived from

QDialog, Ui_GitSubmodulesListDialog

### Class Attributes

None

### Class Methods

None

### Methods

GitSubmodulesListDialog | Constructor

### Static Methods

None

#### GitSubmodulesListDialog (Constructor)

GitSubmodulesListDialog(submodules, parent=None)

Constructor

submodules (list of dictionaries with submodule name, path, URL and branch)
  list of submodule data to be shown
parent (QWidget)
  reference to the parent widget

Up